local Talented = Talented
local Scrub_checks = Scrub.checks

if not Talented or not Scrub_checks then return end

local cbf = Talented.CreateBaseFrame
function Talented:CreateBaseFrame()
	local frame = cbf(self)
	
	local scrubIcon = CreateFrame("Frame", nil, frame)
	frame.scrubIcon = scrubIcon
	scrubIcon:SetWidth(200)
	scrubIcon:SetHeight(16)
	scrubIcon:SetPoint("BOTTOMRIGHT", -14, 20)
    scrubIcon:SetFrameLevel(frame:GetFrameLevel() + 2)
	local text = scrubIcon:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	scrubIcon.text = text
	text:SetAllPoints(scrubIcon)
    text:SetJustifyH("RIGHT")
    text:SetText("Scrub")
	
	scrubIcon:EnableMouse(true)
	scrubIcon:SetScript("OnEnter", function () self:ShowScrubTooltip() end)
	scrubIcon:SetScript("OnLeave", function () GameTooltip:Hide() end)
	
	return frame
end

local uv = Talented.UpdateView
function Talented:UpdateView()
	uv(self)
	
	local icon = self.base.scrubIcon
	
	if self.mode == "apply" then
		icon:Hide()
		return
	end
	local scrubTalents = self.scrubTalents
	if not scrubTalents then
		self.scrubTalents = scrubTalents
	end
	local report, severity = {}, 0
	for _, entry in ipairs(Scrub_checks[self.template.class]) do
		local status, result = pcall(entry.check, scrubTalents)
		if status and result then
			report[#report + 1] = entry
			if entry.severity > severity then
				severity = entry.severity
			end
		end
	end
	if #report == 0 then
		icon:Hide()
	else
		icon:Show()
		icon.text:SetTextColor(unpack(self.scrubColors[severity]))
	end
	self.scrubReport = report
end

Talented.scrubTalents = {
	spent = function (_, tab) return Talented:GetTalentTabCount(Talented.template, tab) end,
	rank = function (_, tab, index) return Talented.template[tab][index] end,
}

Talented.scrubColors = {
	[Scrub.UNKNOWN] = { .5, .5, .5 },
	[Scrub.GREEN] = { 0, 1, 0 },
	[Scrub.YELLOW] = { 1, 1, 0 },
	[Scrub.RED] = { 1, 0, 0 },
}

function Talented:ShowScrubTooltip()
	GameTooltip:SetOwner(self.base.scrubIcon, "ANCHOR_BOTTOMRIGHT")
	GameTooltip:AddLine("Scrub report")
	for _, entry in pairs(self.scrubReport) do
		GameTooltip:AddLine(entry.name, unpack(self.scrubColors[entry.severity]))
	end
    GameTooltip:Show()
end
